Class: Aws::AmplifyBackend::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AmplifyBackend::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-amplifybackend/client.rb,
sig/client.rbs
Overview
An API client for AmplifyBackend. To construct a client, you need to configure a :region and :credentials.
client = Aws::AmplifyBackend::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CloneBackendResponseSuccess, _CreateBackendAPIResponseSuccess, _CreateBackendAuthResponseSuccess, _CreateBackendConfigResponseSuccess, _CreateBackendResponseSuccess, _CreateBackendStorageResponseSuccess, _CreateTokenResponseSuccess, _DeleteBackendAPIResponseSuccess, _DeleteBackendAuthResponseSuccess, _DeleteBackendResponseSuccess, _DeleteBackendStorageResponseSuccess, _DeleteTokenResponseSuccess, _GenerateBackendAPIModelsResponseSuccess, _GetBackendAPIModelsResponseSuccess, _GetBackendAPIResponseSuccess, _GetBackendAuthResponseSuccess, _GetBackendJobResponseSuccess, _GetBackendResponseSuccess, _GetBackendStorageResponseSuccess, _GetTokenResponseSuccess, _ImportBackendAuthResponseSuccess, _ImportBackendStorageResponseSuccess, _ListBackendJobsResponseSuccess, _ListS3BucketsResponseSuccess, _RemoveAllBackendsResponseSuccess, _RemoveBackendConfigResponseSuccess, _UpdateBackendAPIResponseSuccess, _UpdateBackendAuthResponseSuccess, _UpdateBackendConfigResponseSuccess, _UpdateBackendJobResponseSuccess, _UpdateBackendStorageResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#clone_backend(params = {}) ⇒ Types::CloneBackendResponse
This operation clones an existing backend.
-
#create_backend(params = {}) ⇒ Types::CreateBackendResponse
This operation creates a backend for an Amplify app.
-
#create_backend_api(params = {}) ⇒ Types::CreateBackendAPIResponse
Creates a new backend API resource.
-
#create_backend_auth(params = {}) ⇒ Types::CreateBackendAuthResponse
Creates a new backend authentication resource.
-
#create_backend_config(params = {}) ⇒ Types::CreateBackendConfigResponse
Creates a config object for a backend.
-
#create_backend_storage(params = {}) ⇒ Types::CreateBackendStorageResponse
Creates a backend storage resource.
-
#create_token(params = {}) ⇒ Types::CreateTokenResponse
Generates a one-time challenge code to authenticate a user into your Amplify Admin UI.
-
#delete_backend(params = {}) ⇒ Types::DeleteBackendResponse
Removes an existing environment from your Amplify project.
-
#delete_backend_api(params = {}) ⇒ Types::DeleteBackendAPIResponse
Deletes an existing backend API resource.
-
#delete_backend_auth(params = {}) ⇒ Types::DeleteBackendAuthResponse
Deletes an existing backend authentication resource.
-
#delete_backend_storage(params = {}) ⇒ Types::DeleteBackendStorageResponse
Removes the specified backend storage resource.
-
#delete_token(params = {}) ⇒ Types::DeleteTokenResponse
Deletes the challenge token based on the given appId and sessionId.
-
#generate_backend_api_models(params = {}) ⇒ Types::GenerateBackendAPIModelsResponse
Generates a model schema for an existing backend API resource.
-
#get_backend(params = {}) ⇒ Types::GetBackendResponse
Provides project-level details for your Amplify UI project.
-
#get_backend_api(params = {}) ⇒ Types::GetBackendAPIResponse
Gets the details for a backend API.
-
#get_backend_api_models(params = {}) ⇒ Types::GetBackendAPIModelsResponse
Gets a model introspection schema for an existing backend API resource.
-
#get_backend_auth(params = {}) ⇒ Types::GetBackendAuthResponse
Gets a backend auth details.
-
#get_backend_job(params = {}) ⇒ Types::GetBackendJobResponse
Returns information about a specific job.
-
#get_backend_storage(params = {}) ⇒ Types::GetBackendStorageResponse
Gets details for a backend storage resource.
-
#get_token(params = {}) ⇒ Types::GetTokenResponse
Gets the challenge token based on the given appId and sessionId.
-
#import_backend_auth(params = {}) ⇒ Types::ImportBackendAuthResponse
Imports an existing backend authentication resource.
-
#import_backend_storage(params = {}) ⇒ Types::ImportBackendStorageResponse
Imports an existing backend storage resource.
-
#list_backend_jobs(params = {}) ⇒ Types::ListBackendJobsResponse
Lists the jobs for the backend of an Amplify app.
-
#list_s3_buckets(params = {}) ⇒ Types::ListS3BucketsResponse
The list of S3 buckets in your account.
-
#remove_all_backends(params = {}) ⇒ Types::RemoveAllBackendsResponse
Removes all backend environments from your Amplify project.
-
#remove_backend_config(params = {}) ⇒ Types::RemoveBackendConfigResponse
Removes the AWS resources required to access the Amplify Admin UI.
-
#update_backend_api(params = {}) ⇒ Types::UpdateBackendAPIResponse
Updates an existing backend API resource.
-
#update_backend_auth(params = {}) ⇒ Types::UpdateBackendAuthResponse
Updates an existing backend authentication resource.
-
#update_backend_config(params = {}) ⇒ Types::UpdateBackendConfigResponse
Updates the AWS resources required to access the Amplify Admin UI.
-
#update_backend_job(params = {}) ⇒ Types::UpdateBackendJobResponse
Updates a specific job.
-
#update_backend_storage(params = {}) ⇒ Types::UpdateBackendStorageResponse
Updates an existing backend storage resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-amplifybackend/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2188 2189 2190 |
# File 'lib/aws-sdk-amplifybackend/client.rb', line 2188 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2191 2192 2193 |
# File 'lib/aws-sdk-amplifybackend/client.rb', line 2191 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/aws-sdk-amplifybackend/client.rb', line 2161 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AmplifyBackend') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-amplifybackend' context[:gem_version] = '1.66.0' Seahorse::Client::Request.new(handlers, context) end |
#clone_backend(params = {}) ⇒ Types::CloneBackendResponse
This operation clones an existing backend.
90 |
# File 'sig/client.rbs', line 90
def clone_backend: (
|
#create_backend(params = {}) ⇒ Types::CreateBackendResponse
This operation creates a backend for an Amplify app. Backends are automatically created at the time of app creation.
106 |
# File 'sig/client.rbs', line 106
def create_backend: (
|
#create_backend_api(params = {}) ⇒ Types::CreateBackendAPIResponse
Creates a new backend API resource.
125 |
# File 'sig/client.rbs', line 125
def create_backend_api: (
|
#create_backend_auth(params = {}) ⇒ Types::CreateBackendAuthResponse
Creates a new backend authentication resource.
142 |
# File 'sig/client.rbs', line 142
def create_backend_auth: (
|
#create_backend_config(params = {}) ⇒ Types::CreateBackendConfigResponse
Creates a config object for a backend.
209 |
# File 'sig/client.rbs', line 209
def create_backend_config: (
|
#create_backend_storage(params = {}) ⇒ Types::CreateBackendStorageResponse
Creates a backend storage resource.
223 |
# File 'sig/client.rbs', line 223
def create_backend_storage: (
|
#create_token(params = {}) ⇒ Types::CreateTokenResponse
Generates a one-time challenge code to authenticate a user into your Amplify Admin UI.
246 |
# File 'sig/client.rbs', line 246
def create_token: (
|
#delete_backend(params = {}) ⇒ Types::DeleteBackendResponse
Removes an existing environment from your Amplify project.
260 |
# File 'sig/client.rbs', line 260
def delete_backend: (
|
#delete_backend_api(params = {}) ⇒ Types::DeleteBackendAPIResponse
Deletes an existing backend API resource.
275 |
# File 'sig/client.rbs', line 275
def delete_backend_api: (
|
#delete_backend_auth(params = {}) ⇒ Types::DeleteBackendAuthResponse
Deletes an existing backend authentication resource.
292 |
# File 'sig/client.rbs', line 292
def delete_backend_auth: (
|
#delete_backend_storage(params = {}) ⇒ Types::DeleteBackendStorageResponse
Removes the specified backend storage resource.
307 |
# File 'sig/client.rbs', line 307
def delete_backend_storage: (
|
#delete_token(params = {}) ⇒ Types::DeleteTokenResponse
Deletes the challenge token based on the given appId and sessionId.
320 |
# File 'sig/client.rbs', line 320
def delete_token: (
|
#generate_backend_api_models(params = {}) ⇒ Types::GenerateBackendAPIModelsResponse
Generates a model schema for an existing backend API resource.
335 |
# File 'sig/client.rbs', line 335
def generate_backend_api_models: (
|
#get_backend(params = {}) ⇒ Types::GetBackendResponse
Provides project-level details for your Amplify UI project.
352 |
# File 'sig/client.rbs', line 352
def get_backend: (
|
#get_backend_api(params = {}) ⇒ Types::GetBackendAPIResponse
Gets the details for a backend API.
366 |
# File 'sig/client.rbs', line 366
def get_backend_api: (
|
#get_backend_api_models(params = {}) ⇒ Types::GetBackendAPIModelsResponse
Gets a model introspection schema for an existing backend API resource.
381 |
# File 'sig/client.rbs', line 381
def get_backend_api_models: (
|
#get_backend_auth(params = {}) ⇒ Types::GetBackendAuthResponse
Gets a backend auth details.
396 |
# File 'sig/client.rbs', line 396
def get_backend_auth: (
|
#get_backend_job(params = {}) ⇒ Types::GetBackendJobResponse
Returns information about a specific job.
414 |
# File 'sig/client.rbs', line 414
def get_backend_job: (
|
#get_backend_storage(params = {}) ⇒ Types::GetBackendStorageResponse
Gets details for a backend storage resource.
429 |
# File 'sig/client.rbs', line 429
def get_backend_storage: (
|
#get_token(params = {}) ⇒ Types::GetTokenResponse
Gets the challenge token based on the given appId and sessionId.
444 |
# File 'sig/client.rbs', line 444
def get_token: (
|
#import_backend_auth(params = {}) ⇒ Types::ImportBackendAuthResponse
Imports an existing backend authentication resource.
459 |
# File 'sig/client.rbs', line 459
def import_backend_auth: (
|
#import_backend_storage(params = {}) ⇒ Types::ImportBackendStorageResponse
Imports an existing backend storage resource.
477 |
# File 'sig/client.rbs', line 477
def import_backend_storage: (
|
#list_backend_jobs(params = {}) ⇒ Types::ListBackendJobsResponse
Lists the jobs for the backend of an Amplify app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
491 |
# File 'sig/client.rbs', line 491
def list_backend_jobs: (
|
#list_s3_buckets(params = {}) ⇒ Types::ListS3BucketsResponse
The list of S3 buckets in your account.
508 |
# File 'sig/client.rbs', line 508
def list_s3_buckets: (
|
#remove_all_backends(params = {}) ⇒ Types::RemoveAllBackendsResponse
Removes all backend environments from your Amplify project.
521 |
# File 'sig/client.rbs', line 521
def remove_all_backends: (
|
#remove_backend_config(params = {}) ⇒ Types::RemoveBackendConfigResponse
Removes the AWS resources required to access the Amplify Admin UI.
531 |
# File 'sig/client.rbs', line 531
def remove_backend_config: (
|
#update_backend_api(params = {}) ⇒ Types::UpdateBackendAPIResponse
Updates an existing backend API resource.
545 |
# File 'sig/client.rbs', line 545
def update_backend_api: (
|
#update_backend_auth(params = {}) ⇒ Types::UpdateBackendAuthResponse
Updates an existing backend authentication resource.
562 |
# File 'sig/client.rbs', line 562
def update_backend_auth: (
|
#update_backend_config(params = {}) ⇒ Types::UpdateBackendConfigResponse
Updates the AWS resources required to access the Amplify Admin UI.
624 |
# File 'sig/client.rbs', line 624
def update_backend_config: (
|
#update_backend_job(params = {}) ⇒ Types::UpdateBackendJobResponse
Updates a specific job.
646 |
# File 'sig/client.rbs', line 646
def update_backend_job: (
|
#update_backend_storage(params = {}) ⇒ Types::UpdateBackendStorageResponse
Updates an existing backend storage resource.
663 |
# File 'sig/client.rbs', line 663
def update_backend_storage: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2181 2182 2183 |
# File 'lib/aws-sdk-amplifybackend/client.rb', line 2181 def waiter_names [] end |